@@ -57,10 +57,10 @@ class Pool(threading.Thread):
         encoding='',
     )
 
-    def __init__(self, maxconnects, **kwargs):
+    def __init__(self, maxconnects, qsize=0, **kwargs):
         self._multi = Multi(**kwargs)
         self._multi.maxconnects = maxconnects
-        self._queue = Queue()
+        self._queue = Queue(qsize)
         self._size = maxconnects
 
         self._data = {}
